LinkList class

Constructors

LinkList(String organizationId, ApiAdapter apiAdapter)

Properties

apiAdapter ApiAdapter
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
organizationId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webviewUrl String?
getter/setter pair

Methods

create(CreateLinkListPayload payload) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited